@@ -2,10 +2,10 @@ from classeval.classeval import (
     summary,
     two_class,
     MCC,
-    pr_curve,
-    proba,
-    ROC,
+    AP,
     CAP,
+    ROC,
+    proba_curve,
     load_example,
 )
 
@@ -13,7 +13,7 @@ import classeval.confmatrix as confmatrix
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 # module level doc-string
 __doc__ = """
@@ -24,11 +24,25 @@ Description
 -----------
 classeval is a python package that contains functionalities and plots for fast and easy classifier evaluation.
 
+
 Example
 -------
+>>> from sklearn.model_selection import train_test_split
+>>> from sklearn.ensemble.gradient_boosting import GradientBoostingClassifier
+>>> gb = GradientBoostingClassifier()
+>>>
 >>> import classeval as clf
->>> results = clf.eval(model)
->>> fig,ax = clf.plot(model)
+>>>
+>>> X, y = clf.load_example('breast')
+>>> X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2)
+>>>
+>>> model = gb.fit(X_train, y_train)
+>>> y_proba = model.predict_proba(X_test)
+>>> y_pred = model.predict(X_test)
+>>>
+>>> results = clf.summary(y_test, y_proba[:,1])
+>>> print(results['report'])
+
 
 References
 ----------
